==> jc-1.4.0.tar.gz: java/lang/ref/SoftReference.h <==
// public class java.lang.ref.SoftReference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 1c8c705a2ba46198 java_lang_ref_SoftReference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_SoftReference_H_
#define _JC_java_lang_ref_SoftReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_SoftReference$sub_refs	_jc_java_lang_ref_SoftReference$sub_refs;
typedef struct _jc_java_lang_ref_SoftReference$sub_nonrefs	_jc_java_lang_ref_SoftReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_SoftReference$refs	_jc_java_lang_ref_SoftReference$refs;
typedef struct _jc_java_lang_ref_SoftReference$nonrefs	_jc_java_lang_ref_SoftReference$nonrefs;
typedef struct _jc_java_lang_ref_SoftReference$object	_jc_java_lang_ref_SoftReference$object;

typedef const struct _jc_java_lang_ref_SoftReference$vmethods	_jc_java_lang_ref_SoftReference$vmethods;
typedef const struct _jc_java_lang_ref_SoftReference$vtable	_jc_java_lang_ref_SoftReference$vtable;
typedef const struct _jc_java_lang_ref_SoftReference$vtype	_jc_java_lang_ref_SoftReference$vtype;

// Constructors
extern void _jc_java_lang_ref_SoftReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_ref_SoftReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_SoftReference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_SoftReference$method_info$get$a27f05608bfbd09b;

// Virtual methods structure
struct _jc_java_lang_ref_SoftReference$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *);
};

// Vtable
struct _jc_java_lang_ref_SoftReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_SoftReference$vmethods	java_lang_ref_SoftReference;
};

// Vtype
struct _jc_java_lang_ref_SoftReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_SoftReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_SoftReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_SoftReference$refs {
    _jc_java_lang_ref_SoftReference$sub_refs	java_lang_ref_SoftReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_SoftReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_SoftReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_SoftReference$sub_nonrefs	java_lang_ref_SoftReference;
};

// Object instance structure
struct _jc_java_lang_ref_SoftReference$object {
	_jc_java_lang_ref_SoftReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_SoftReference$vtype	*vtype;
	_jc_java_lang_ref_SoftReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_SoftReference$vtype _jc_java_lang_ref_SoftReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_SoftReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_SoftReference$class_object;

#endif	/* _JC_java_lang_ref_SoftReference_H_ */

==> jc-1.4.6.tar.gz: java/lang/ref/SoftReference.h <==
// public class java.lang.ref.SoftReference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 1c8c705a2ba46198 java_lang_ref_SoftReference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_SoftReference_H_
#define _JC_java_lang_ref_SoftReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_SoftReference$sub_refs	_jc_java_lang_ref_SoftReference$sub_refs;
typedef struct _jc_java_lang_ref_SoftReference$sub_nonrefs	_jc_java_lang_ref_SoftReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_SoftReference$refs	_jc_java_lang_ref_SoftReference$refs;
typedef struct _jc_java_lang_ref_SoftReference$nonrefs	_jc_java_lang_ref_SoftReference$nonrefs;
typedef struct _jc_java_lang_ref_SoftReference$object	_jc_java_lang_ref_SoftReference$object;

typedef const struct _jc_java_lang_ref_SoftReference$vmethods	_jc_java_lang_ref_SoftReference$vmethods;
typedef const struct _jc_java_lang_ref_SoftReference$vtable	_jc_java_lang_ref_SoftReference$vtable;
typedef const struct _jc_java_lang_ref_SoftReference$vtype	_jc_java_lang_ref_SoftReference$vtype;

// Constructors
extern void _jc_java_lang_ref_SoftReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ref_SoftReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_SoftReference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_SoftReference$method_info$get$a27f05608bfbd09b;

// Virtual methods structure
struct _jc_java_lang_ref_SoftReference$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_SoftReference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ref_SoftReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_SoftReference$vmethods	java_lang_ref_SoftReference;
};

// Vtype
struct _jc_java_lang_ref_SoftReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_SoftReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_SoftReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_SoftReference$refs {
    _jc_java_lang_ref_SoftReference$sub_refs	java_lang_ref_SoftReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_SoftReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_SoftReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_SoftReference$sub_nonrefs	java_lang_ref_SoftReference;
};

// Object instance structure
struct _jc_java_lang_ref_SoftReference$object {
	_jc_java_lang_ref_SoftReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_SoftReference$vtype	*vtype;
	_jc_java_lang_ref_SoftReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_SoftReference$vtype _jc_java_lang_ref_SoftReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_SoftReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_SoftReference$class_object;

#endif	/* _JC_java_lang_ref_SoftReference_H_ */
